Opinions by Month/Year | Eighth Circuit | United States Court of Appeals

Skip to main content

United States Court of Appeals

# for the Eighth Circuit

Michael E. Gans, Clerk of Court
Text Size:

- Decrease font size
- Reset font size
- Increase font size

DISCLAIMER: The following unofficial case summaries are prepared by the clerk's office
as a courtesy to the reader. They are not part of the opinion of the court.

    [ May 03, 2013 ]

    121617P.pdf   05/03/2013  United States  v.  Adekunle Olufemi Adetiloye
       U.S. Court of Appeals Case No:  12-1617
                              and No:  12-1919
       U.S. District Court for the District of North Dakota - Fargo
       [PUBLISHED] [Bye, Author, with Wollman and Benton, Circuit Judges]
       Criminal case - Sentencing. District court thoroughly considered the
       3553(a) factors at the sentencing hearing, issued a 17-page sentencing
       memorandum and provided a sufficient explanation for its sentencing
       decision; district court did not err in denying defendant a reduction for
       acceptance of responsibility where defendant contested factual statements
       and nearly all applicable enhancements in the PSR; no error in imposing
       an enhancement under Guidelines Sec. 3B1.1(a) for leadership role in the
       offense; no error in imposing an upward enhancement on the ground the
       offense level substantially understated the seriousness of the offense;
       where the government failed to provide documentation with the required
       specificity and reliability to establish the amount of restitution, the court
       should have postponed the restitution proceedings for the gathering and
       presentation of additional evidence; similarly, the district court erred in
       ordering forfeiture in the limited amount set out in its restitution order;
       the restitution and forfeiture orders are vacated and remanded for further
       proceeding regarding the losses the victims sustained and the proceeds
       defendant gained from the scheme.

    123151U.pdf   05/03/2013  United States  v.  Jeffrey Rand
       U.S. Court of Appeals Case No:  12-3151
       U.S. District Court for the Western District of Arkansas - Hot Springs
       [UNPUBLISHED] [Per Curiam - Before Bye, Arnold and Shepherd,
       Circuit Judges]
       Criminal case - Sentencing. Anders case. District court properly
       considered the sentencing factors and the sentence it imposed was not
       unreasonable; defendant withdrew his objection to the restitution portion
       of his sentence and waived his right to appeal the restitution order.

    123373U.pdf   05/03/2013  George H. Kalberer  v.  Star Tribune
       U.S. Court of Appeals Case No:  12-3373
       U.S. District Court for the District of Minnesota - Minneapolis
       [UNPUBLISHED] [Per Curiam - Before Wollman, Bowman and
       Gruender, Circuit Judges]
       Civil case - Employment Discrimination. Defendants' summary
       judgment on plaintiff's Age Discrimination in Employment Act
       claims affirmed without comment.

    123977U.pdf   05/03/2013  Yussuf Hamid  v.  JPMorgan Chase Bank
       U.S. Court of Appeals Case No:  12-3977
       U.S. District Court for the District of Minnesota - Minneapolis
       [UNPUBLISHED] [Per Curiam - Before Bye, Arnold and Shepherd,
       Circuit Judges]
       Civil case - Foreclosure. Dismissal of a "show-me-the-note" action
       affirmed without comment.

    136011P.pdf   05/03/2013  David Lynd  v.  Charles Ries
       U.S. Court of Appeals Case No:  13-6011
       U.S. Bankruptcy Court for the District of Minnesota - Minneapolis
       [PUBLISHED] [Federman, Author, with Nail and Saladino,
       Bankruptcy Judges]
       Bankruptcy Appellate Panel. To the extent Lynd requested the
       bankruptcy court to deviate from the Code and order that his
       restitution claim be paid from some source not authorized by
       the Code, the bankruptcy court was without authority to grant
       such relief, and the court did not err in denying his request.

    [ May 02, 2013 ]

    121713P.pdf   05/02/2013  Harleysville Insurance Company  v.  Physical Distribution Services
       U.S. Court of Appeals Case No:  12-1713
       U.S. District Court for the District of Minnesota - Minneapolis
       [PUBLISHED] [Riley, Author, with Colloton and Gruender, Circuit Judges]
       Civil case - Contracts. The contract between Physical Distribution and
       Miller Transporters required Physical Distribution to indemnify Miller for
       liability it had incurred from an injury to a leased employee; the insurance
       contract between Physical Distribution and Harleysville, which extended
       coverage to Physical Distribution's indemnification of third parties for
       tort liability caused in whole or in part by Physical Distribution or those
       acting on its behalf, required Harleysville to cover the resulting cost to
       Physical Distribution. Judge Colloton, dissenting.

    122716U.pdf   05/02/2013  United States  v.  Shawn Jones
       U.S. Court of Appeals Case No:  12-2716
       U.S. District Court for the Northern District of Iowa - Ft. Dodge
       [UNPUBLISHED] [Per Curiam - Before Riley, Chief Judge, and Bye
       and Benton, Circuit Judges]
       Criminal case - Criminal law. No error in admitting results of a photo
       lineup as it was not impermissible suggestive and defendant had an
       opportunity at trial to attack the credibility of the witness's identification;
       evidence was sufficient to support defendant's conviction for conspiracy
       to distribute methamphetamine.

    [ May 01, 2013 ]

    103137P.pdf   05/01/2013  B & B Hardware  v.  Hargis Industries
       U.S. Court of Appeals Case No:  10-3137
                              and No:  11-1247
       U.S. District Court for the Eastern District of Arkansas - Little Rock
       [PUBLISHED] [Shepherd, Author, with Loken and Colloton, Circuit Judges]
       Civil case - Trademarks. For the court's prior opinions in the case, see
       B&B Hardware, Inc. v. Hargis Industries, Inc., 569 F.3d 383 (8th Cir.
       2009); and B&B Hardware, Inc. v. Hargis Industries, 252 F.3d 1010 (8th
       Cir. 2001). Assuming that Trademark Trial and Appeal Board decisions
       may be entitled to preclusive effect, such application is not appropriate
       here because the same likelihood-of-confusion issues were not decided by
       the Board as were brought in the action before the district court; the court
       rejects B&B's argument that the Board's factual findings from a
       trademark registration case are entitled to deference by the district court;
       district court did not abuse its discretion by refusing to admit the Board's
       decision into evidence as over the course of the seven-day trial the jury
       was presented with evidence regarding likelihood of confusion as it
       pertained to the factors under which the jury decided the claim of
       trademark infringement and the probative value of the Board's ultimate
       conclusion was minimal; the district court erred in including an award of
       attorneys' fees to Hargis for B&B's prior appeal as that appeal resulted in
       a ruling in B&B's favor and was not groundless or unreasonable; on
       remand, the court should amend its award of fees by deducting the fees
       for the appeal. Judge Colloton, dissenting.

    122913P.pdf   05/01/2013  United States  v.  Nathan Ozmon
       U.S. Court of Appeals Case No:  12-2913
       U.S. District Court for the Southern District of Iowa - Davenport
       [PUBLISHED] [Murphy, Author, with Beam and Bye, Circuit Judge]
       Criminal case - Sentencing. Government did not breach the cooperation
       agreement when it used defendant's self incriminating statements from
       his proffer interview; sentence imposed was not substantively
       unreasonable.

    123535P.pdf   05/01/2013  United States  v.  Jesus Quintero-Felix
       U.S. Court of Appeals Case No:  12-3535
       U.S. District Court for the Northern District of Iowa - Sioux City
       [PUBLISHED] [Gruender, Author, with Loken, Circuit Judge, and
       Phillips, District Judge]
       Criminal case - Criminal case. Police officer did not unduly extend the
       traffic stop once he had issued a warning ticket to defendant and returned
       his documents as the officer had reasonable suspicion to extend the stop
       based on defendant's behavior, his answers to the officer's questions and
       conflicts between defendant's answers and his passenger's; even
       assuming the officer lacked reasonable suspicion, defendant consented to
       extension of the stop; evidence was sufficient to support defendant's
       convictions for conspiracy to distribute methamphetamine and aiding and
       abetting its distribution.

    123704U.pdf   05/01/2013  Robert Rutz  v.  Discover Financial Services
       U.S. Court of Appeals Case No:  12-3704
       U.S. District Court for the Western District of Arkansas - Fayetteville
       [UNPUBLISHED] [Per Curiam - Before Wollman, Bowman and
       Gruender, Circuit Judges]
       Civil case - Arbitration. In an action to overturn an adverse arbitration
       decision regarding domain names, the district court did not err in
       dismissing the case as plaintiff failed to state a claim under 15 U.S.C.
       Sec. 1114(2)(D)(v) or the RICO statute; nor did the complaint state a
       contract claim or a tort claim.